## Description
Brief description of changes

## Type of Change
- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Performance improvement
- [ ] Code refactoring
- [ ] Test improvements
- [ ] Build/CI improvements

## Related Issues
Fixes #(issue number)
Closes #(issue number)
Related to #(issue number)

## Changes Made
- [ ] Added new feature
- [ ] Fixed bug
- [ ] Updated documentation
- [ ] Added tests
- [ ] Updated dependencies
- [ ] Other (please describe)

## Testing
- [ ] Tests pass locally
- [ ] New tests added for new functionality
- [ ] All existing tests pass
- [ ] Manual testing completed
- [ ] Edge cases tested

## Checklist
- [ ] Code follows the project's style guidelines
- [ ] Self-review of code completed
- [ ] Code is properly commented
- [ ] Documentation updated (if applicable)
- [ ] No new warnings introduced
- [ ] Breaking changes documented
- [ ] CHANGELOG.md updated (if applicable)
- [ ] Type hints added (if applicable)
- [ ] Tests added/updated (if applicable)

## Screenshots (if applicable)
Add screenshots to help explain your changes.

## Additional Notes
Any additional information that reviewers should know.

## Breaking Changes
If this PR contains breaking changes, please describe them here and how to migrate.

## Performance Impact
If this PR affects performance, please describe the impact.

## Security Considerations
If this PR affects security, please describe the considerations.
